@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from InstantMessage import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestIMAVManagerHelper (NSObject):
     def getPixelBufferPixelFormat_(self, _):
         return 10
@@ -37,7 +42,7 @@ class TestIMAVManager (TestCase):
         self.assert_( isinstance(protocols.IMVideoDataSource, objc.informal_protocol) )
 
         self.assertArgIsOut(TestIMAVManagerHelper.getPixelBufferPixelFormat_, 0)
-        self.assertArgHasType(TestIMAVManagerHelper.getPixelBufferPixelFormat_, 0, b'o^I')
+        self.assertArgHasType(TestIMAVManagerHelper.getPixelBufferPixelFormat_, 0, b'o^' + objc._C_UINT)
 
         self.assertResultIsBOOL(TestIMAVManagerHelper.renderIntoPixelBuffer_forTime_)
         self.assertArgIsIn(TestIMAVManagerHelper.renderIntoPixelBuffer_forTime_, 1)
